@@ -14,7 +14,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-__version__ = '0.0.5'
+__license__ = 'GPLv3'
+__version__ = '1.0.0'
 
 run_help = '''TBlock - An anticapitalist ad-blocker that uses the hosts file
 Copyright (c) 2021 Twann <twann@ctemplar.com>
@@ -31,14 +32,16 @@ usage: tblock <operation> <options>
   -b  --block        [domain]             Block a domain
   -r  --redirect     [domain]  [ip]       Redirect a domain to another address
   -d  --delete-rule  [domain]             Delete a rule for a domain
-  -l  --list-rules   <options>            List active rules
+  -l  --list-rules   [options]            List active rules
 * Filters
-  -S  --subscribe    <options> [filter]   Subscribe to a new filter
-  -R  --remove       <options> [filter]   Remove a filter (unsubscribe)
-  -U  --update       <options> [filter]   Update a filter
-  -M  --mod          {a|b|r}   [filter]   Change permissions of a filter
+  -S  --subscribe    [filter]             Subscribe to a new filter
+  -C  --add-custom   [id]     [file/url]  Subscribe to a custom filter
+  -R  --remove       [filter]             Remove a filter (unsubscribe)
+  -U  --update       [filter]             Update a filter
+  -M  --mod          [a|b|r]  [filter]    Change permissions of a filter
+  -X  --change-id    [filter] [new-id]    Change the ID of a custom filter
   -I  --info         [filter]             Show information about a filter
-  -L  --list         <options>            List all filters
+  -L  --list         [options]            List all filters
   -Y  --sync                              Update remote filters repository
 * Hosts
   -H  --update-hosts                      Update hosts file
@@ -48,23 +51,21 @@ usage: tblock <operation> <options>
 * General
   -f  --force                             Do not prompt user for anything
 * Rules
-  -s  --standard     [filter]             Only show standard rules
+  -t  --standard                          Only show standard rules
   -u  --user                              Only show user rules
 * Filters
-  -c  --custom       [file/url]           Subscribe to a custom filter
   -y  --sync                              Update remote filters repository
-  -m  --mod          {a|b|r}              Configure filter permissions when subscribing
   -c  --custom                            List only custom filters
-  -s  --subscribed                        List only subscribed filters
+  -k  --subscribed                        List only subscribed filters
   -n  --unsubscribed                      List only unsubscribed filters
-  -w  --available                         List only filters available in remote repository
+  -w  --on-remote-repo                    List only filters available on remote repository
 
 For more information, see tblock(1)'''
 
 run_converter_help = '''TBlockc - TBlock's built-in filter converter
 Copyright (c) 2021 Twann <twann@ctemplar.com>
 
-usage: tblockc <options> {-s|--syntax} [syntax] [file] [output_file]
+usage: tblockc [file] {-s,--syntax} [syntax] {-o,--output} [output_file] <options>
 
 <options>
 * General
@@ -72,10 +73,11 @@ usage: tblockc <options> {-s|--syntax} [syntax] [file] [output_file]
   -f  --force                             Do not prompt user for anything
   -v  --version                           Show version information
 * Converting
-  -r  --rules        {a|b|r}              Choose which policies to allow during converting
+  -0  --zero                              Redirect domains to 0.0.0.0 instead of 127.0.0.1 (hosts)
   -c  --comments                          Also convert comments
-  -o  --original     <syntax>             Specify the original syntax of the filter to convert
-  -s  --syntax       <syntax>             Specify the new syntax to use (required)
+  -o  --output       [file]               Original syntax of the filter to convert (required)
+  -s  --syntax       [syntax]             New syntax to use (required)
+  -i  --input-syntax [syntax]             Specify the syntax of the filter
 * Other
   -g  --get-syntax   [file]               Scan a filter to get its syntax
 
